@@ -2,7 +2,7 @@ package Test2::Harness::Finder;
 use strict;
 use warnings;
 
-our $VERSION = '1.000149';
+our $VERSION = '1.000150';
 
 use Test2::Harness::Util qw/clean_path mod2file/;
 use Test2::Harness::Util::JSON qw/decode_json encode_json/;
@@ -336,7 +336,7 @@ sub add_rerun_to_search {
         $data = \%files;
     }
 
-    my @add = grep {
+    my @add = map { $data->{$_}->{add} // $_ } grep {
         my $entry = $data->{$_};
 
         my $keep = $mode_hash->{all} ? 1 : 0;
